# Seagrass

[![PyPI package version](https://img.shields.io/pypi/v/seagrass.svg)](https://pypi.org/project/seagrass)
[![Docs](https://readthedocs.org/projects/seagrass/badge/?version=latest)](https://seagrass.readthedocs.io/en/latest/?badge=latest)
[![Build status](https://github.com/kernelmethod/Seagrass/actions/workflows/CI.yml/badge.svg?branch=main)](https://github.com/kernelmethod/Seagrass/actions/workflows/CI.yml/)

*A Python event auditing and profiling multitool*

Seagrass is a Python library for hooking and auditing events in your Python
code.

*Note: Seagrass is only supported for Python versions >= 3.8*

## Installation

You can install the latest version of Seagrass using `pip`:

```
pip install seagrass
```

## Getting started

To learn how to use Seagrass, check out the [quick start
guide](https://seagrass.readthedocs.io/en/latest/quickstart.html) in the library
documentation.
